@@ -59,7 +59,7 @@
 
 #' @export
 "+.tensorflow.tensor" <- function(a, b) {
-  tf$add(a, b)
+  if (missing(b)) a else tf$add(a, b)
 }
 
 #' @export
@@ -208,6 +208,12 @@
 }
 
 
+#' @export
+expm1.tensorflow.tensor <- function(x) {
+  tf$math$expm1(x)
+}
+
+
 #' @export
 "log.tensorflow.tensor" <- function(x, base = exp(1)) {
   if (is_tensor(base) || base != exp(1)) {
